# Background & Summary (Max 700 words)

## Introduction to EIT

Electrical Impedance Tomography (EIT) is a safe, portable and inexpensive imaging method, which can produce images of the internal conductivity of an object, by injecting insensible electrical currents into an object at a frequency between several kHz and several MHz. EIT has the potential to image brain function and pathology, with current applications including localization of epileptic foci \cite{Bagshaw\_2003} \cite{Fabrizi\_2006}, imaging normal haemodynamic brain function \cite{Tidswell\_2001} and fast neural activity \cite{Aristovich\_2016}.


## EIT of Stroke

The ability to rapidly differentiate haemorrhagic and ischaemic stroke, to enable appropriate treatment, is one of the most important challenges in stroke management and care \cite{Donnan\_2009}. Thrombolytic “clot-busting” drugs are a treatment for acute ischaemic stroke which must be administered within four and a half hours after the onset of symptoms \cite{Hacke\_2008}. To enable effective treatment within this restricted time window, new methods are required to distinguish haemorrhagic from ischaemic stroke, without waiting for hospital admission and a CT or MRI scan. It is estimated that in most countries, only 4% to 10% of potentially eligible patients receive the treatment \cite{Bambauer_2006}, primarily because of delayed admission to stroke centres.

The impedance contrast between 'healthy' brain tissue, blood and ischaemic brain tissue (\(\Omega_{blood}\) < \(\Omega_{brain}\) < \(\Omega_{ischaemia}\)) \cite{Dowrick_2015} means that the situation is well suited for exploration using EIT.

EIT has the potential to provide an inexpensive portable unit for use in ambulances or GP surgeries which would revolutionise thrombolytic management of stroke by providing imaging at the point of contact. 


## EIT Imaging

A number of reconstruction algorithms have been proposed for the imaging of stroke using impedance data, including time, frequency \cite{Malone\_2014} and absolute imaging methods \cite{Ma\_2014}. Of these, frequency difference is the most promising for a clinical setting, as it allows image construction to take place using data collected at a single point in time, whereas time difference algorithms require a 'baseline' data set, recorded before the stroke onset. Frequency difference imaging presents a substantially greater technical challenge, in terms of the algorithmic and computational complexity, and effective algorithms have not yet been developed for use with human data.


## EIT Hardware
An EIT system is typically comprised of an electrode array, current source, voltage measurement unit and switching circuitry to direct an injection current to a particular subset of electrodes. The EIT system used in this study was developed at UCL  \cite{Avery_2017} and uses a Keithley 6221 Current Source (Keithley Instruments, Cleveland, Ohio, USA), BioSemi EEG Recorder (Biosemi, Amsterdam, The Netherlands), EasyCap EEG electrodes (EasyCap, Germany) and a custom PCB for current routing and system control.

A sinosoudial current, with a given amplitude and frequency (typically in the 100 µA and kHz ranges), is injected between a pair of electrodes, referred to as an _injection_, and voltages are measured at all electrodes in parallel \ref{EITexample}. A single EIT _measurement_ is the demodulate voltage amplitude at a single electrode, averaged over a certain number of periods of the waveform. The electrodes used for injection are excluded from the measurement set. A complete set of measurements, referred to as a _protocol_,  is collected by repeating the current injection at a number of different injection pairs. The entire set of _n_ voltage measurements, equal to the number of injection pairs multiplied by the number of measurement electrodes, is referred to as a _frame_ of data. __TODO: More on digital triggers? What is recorded etc__ Digital triggers, used to indicate the beginning/end of each frequency range, frame and individual injection, are also recorded by the BioSemi.

## Frequency Difference EIT Dataset

A multi-frequency EIT dataset has been collected in 23 stroke patients and 10 healthy volunteers, in collaboration with the Hyper Acute Stroke Unit (HASU) at University College London Hospital (UCLH). For each individual, three frames were collected, each at 17 frequencies between 5Hz and 2kHz  with 930 individual measurements collected at each frequency. Additionally, a CT and/or MRI was performed on each of the 23 stroke patients and a clinical assesement carried out by medical personel.

## Time Difference EIT Dataset
In each of the healthy volunteers, and four of the stroke patients, an additional data set was collected, where the same measurement process was repeated after 24 hours, to obtain data suitable for time difference EIT analysis.