# Methods


## Ethical approval, patient selection and consent
All experiments on human subjects were approved by the UCL REC, the local Reserach Ethics Committee, and NHS/HSC R&D (IRAS ID: 168765). The following patient inclusion/exclusion criteria was established:


Inclusion criteria
-	Adult patient (≥18year, no upper age limit). 
-	Clinical diagnosis of cortical ischaemic stroke or lobar intracerebral haemorrhage.
-	The stroke has a greatest axial diameter > 1.5 cm on CT/MRI OR the patient has NIHSS > 5.
-	Able to undergo the EIT assessment within 7 days of onset.

Exclusion criteria
-	Expected to require critical transfer or intervention, ITU admission or to be transferred out of the HASU for any other reasons. 
-	Unlikely to tolerate the procedure (e.g. agitation on admission), or a very high likelihood of death within 48 hours of stroke onset.
-	Additional medical illness (such as Epilepsy, skin problem, head or face metal implants) or technical aspect (such as no bed available on HASU) that interferes with EIT assessments.

Potential participants were first identified by the clinical care team, who also initiated first discussions with the patient. It they were willing to participate, written consent was obtained. Where the patient lacked the capacity to give consent, assent was given by a member of the family. 


## Electrode arrangement and application

Recordings were performed using 32 EEG electrodes (EasyCap, Germany), using the configuration described in \cite{Tidswell\_2001}, which includes 21 locations from the EEG 10-20 standard and 11 additional electrodes. For these experiments, the locations were updated to match the nearest equivalents in either the 10-10 or 10-5 extensions \cite{Oostenveld_2001}.

All electrodes sites were cleaned with surgical spirit, abraded using Nuprep gel (Weaver and Co., USA) and the electrodes affixed using Elefix conductive paste (Nihon Kohden, Japan).


## EIT Data Collection
EIT data was collected at seventeen frequencies (Hz), with the current amplitude at each frequency set to the maximum allowed under the guidelines set out in IEC 60601 (Table \ref{EIT-Setup}). In order to reduce the total data collection time, the number of current injection periods applied was reduced at lower frequencies. The experimental protocol was performed three times, for a total duration of  20 minutes.

**Additional measurments taken?**

## MRI and CT data
As part of the clinical diagnosis process in the HASU, each patient underwent a MRI and/or CT scan (DICOM format), which is included in this repository. All MRI/CT data was anonymised by removing any identifying data from the DICOM file, using DICOM Clener.

## Data processing

A MATLAB script __InsertScriptName.m__, detailing all of the steps taken to generate the final data set from the EEG data files, is included with the data repository.

The EEG data from the bdf source file is converted to a double precision array, with dimensions n\_electrodes x n\_samples. n\_electrodes is 32 in all cases, n\_samples is equal to the recording time in seconds multipled by the sampling frequency, Fs.
The digital triggers, also extracted from the bdf file, are used to partition the data according to frequency, into 17 segments, each comprising three frames of data.

Each segment of data is filtered (__TODO: add filter details to table 1?__) around the injection frequency, and demodulated to give the voltage amplitude \ref{DataProcessing}. Further segmentation is carried out by splitting the data into individual injections. The voltage amplitude is averaged over all cycles recorded for each injection. To exclude filter/demodulation artefacts, the first and last two sinwave cycles are removed before averaging.

The gain of the BioSemi has a known frequency dependence, with the -3dB point at 3kHz. In order to account for this, voltages at each frequency are divided by the apporpriate gain value to normalise all voltages. The three frames of data collected at each frequency are averaged together, to produce the final data set.

Data cleaning was carried out by __TODO: what were the criteria?__. Both the cleaned and uncleaned data is included in the published dataset, allowing alternative cleaning criteria to be used.

